@@ -68,8 +68,9 @@ var (
 	flagLogPid     = flag.Bool("log-pid", false, fmt.Sprintf("append PIDs (%s=1)", EnvLogPid))
 	flagLogJS      = flag.Bool("log-js", false, fmt.Sprintf("enable jobserver messages logging (%s=1)", EnvLogJS))
 
-	LogMutex   sync.Mutex
-	LogLenPrev int
+	LogMutex     sync.Mutex
+	KeyEraseLine string
+	LogWasStatus bool
 )
 
 func init() {
@@ -83,15 +84,12 @@ func init() {
 	CWarn = string(t.Escape.Magenta)
 	CJS = string(t.Escape.White)
 	CReset = string(t.Escape.Reset)
+	KeyEraseLine = fmt.Sprintf("%s[K", CReset[0:1])
 }
 
-func fillUpToTermSize(s, end string) string {
-	sLen := len(s)
-	if sLen < LogLenPrev {
-		s += strings.Repeat(" ", LogLenPrev-sLen)
-		LogLenPrev = sLen
-	} else {
-		LogLenPrev = sLen
+func erasedStatus(s, end string) string {
+	if LogWasStatus {
+		s += KeyEraseLine
 	}
 	return s + end
 }
@@ -103,10 +101,10 @@ func trace(level, format string, args ...interface{}) {
 	}
 	switch level {
 	case CNone:
+		p = StderrPrefix + p + fmt.Sprintf(format, args...)
 		LogMutex.Lock()
-		os.Stderr.WriteString(fillUpToTermSize(
-			StderrPrefix+p+fmt.Sprintf(format, args...), "\n",
-		))
+		os.Stderr.WriteString(erasedStatus(p, "\n"))
+		LogWasStatus = false
 		LogMutex.Unlock()
 		return
 	case CDebug:
@@ -142,7 +140,8 @@ func trace(level, format string, args ...interface{}) {
 	msg := fmt.Sprintf(format, args...)
 	msg = StderrPrefix + colourize(level, p+strings.Repeat(". ", Level)+msg)
 	LogMutex.Lock()
-	os.Stderr.WriteString(fillUpToTermSize(msg, "\n"))
+	os.Stderr.WriteString(erasedStatus(msg, "\n"))
+	LogWasStatus = false
 	LogMutex.Unlock()
 }
 
