@@ -22,6 +22,7 @@ package main
 import (
 	"errors"
 	"fmt"
+	"io"
 	"os"
 	"path"
 	"path/filepath"
@@ -224,7 +225,7 @@ RecordOODTgt:
 	if err = unix.Flock(int(FdOODTgtsLock.Fd()), unix.LOCK_EX); err != nil {
 		panic(err)
 	}
-	if _, err = FdOODTgts.Seek(0, os.SEEK_END); err != nil {
+	if _, err = FdOODTgts.Seek(0, io.SeekEnd); err != nil {
 		panic(err)
 	}
 	if _, err := FdOODTgts.WriteString(p + "\x00"); err != nil {
